@@ -2,6 +2,9 @@ from superpowered.main import BASE_URL, _format_http_response, get_headers
 import requests
 
 class Incantation:
+    """
+    The Incanation class is used to create, update, and delete incantations.
+    """
     def __init__(self, title: str, text: str, supp_id: str = None, description: str = None, incantation_id: str = None):
         self.incantation_id = incantation_id
         self.title = title
@@ -64,14 +67,18 @@ def get_incantations():
         incantations[incantation['id']] = inc
     return incantations
 
-# create_incantation() is a convenience function that creates an Incantation object and then calls its create() method
 def create_incantation(title: str, text: str):
+    """
+    create_incantation() is a convenience function that creates an Incantation object and then calls its create() method
+    """
     incantation_obj = Incantation(title=title, text=text)
     body_resp = incantation_obj.create()
     return incantation_obj
 
-# get_incantation() is a convenience function that returns an Incantation object for an existing incantation, given its title
 def get_incantation(incantation_title: str):
+    """
+    get_incantation() is a convenience function that returns an Incantation object for an existing incantation, given its title
+    """
     incantations = get_incantations()
     
     # create incantation name to id map - incantations is a dict of incantation objects keyed on incantation_id
@@ -89,8 +96,10 @@ def get_incantation(incantation_title: str):
     else:
         raise Exception('Incantation title not found: ' + incantation_title)
 
-# update_incantation() is a convenience function that updates an existing incantation, given its title
 def update_incantation(incantation_title: str, new_text: str = None, new_title: str = None):
+    """
+    update_incantation() is a convenience function that updates an existing incantation, given its title
+    """
     incantation_obj = get_incantation(incantation_title)
     if new_title is not None:
         incantation_obj.title = new_title
@@ -99,8 +108,10 @@ def update_incantation(incantation_title: str, new_text: str = None, new_title:
     body_resp = incantation_obj.update()
     return incantation_obj
 
-# list_incantations() is a convenience function that returns a dictionary of all Incantation objects for an account
 def list_incantations(verbose=True):
+    """
+    list_incantations() is a convenience function that returns a dictionary of all Incantation objects for an account
+    """
     incantations = get_incantations()
     if verbose:
         print ("\nIncantations:")
